package com.boman.web.core.service.vaccineInfo.impl;

import java.util.List;

import com.boman.common.core.utils.DateUtils;
import com.boman.web.core.service.vaccineInfo.IVaccineInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.boman.web.core.mapper.VaccineInfoMapper;
import com.boman.web.core.domain.VaccineInfo;

/**
 * 疫苗信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2021-09-05
 */
@Service
public class VaccineInfoServiceImpl implements IVaccineInfoService
{
    @Autowired
    private VaccineInfoMapper vaccineInfoMapper;

    /**
     * 查询疫苗信息
     * 
     * @param id 疫苗信息ID
     * @return 疫苗信息
     */
    @Override
    public VaccineInfo selectVaccineInfoById(Long id)
    {
        return vaccineInfoMapper.selectVaccineInfoById(id);
    }

    /**
     * 查询疫苗信息列表
     * 
     * @param vaccineInfo 疫苗信息
     * @return 疫苗信息
     */
    @Override
    public List<VaccineInfo> selectVaccineInfoList(VaccineInfo vaccineInfo)
    {
        return vaccineInfoMapper.selectVaccineInfoList(vaccineInfo);
    }

    /**
     * 新增疫苗信息
     * 
     * @param vaccineInfo 疫苗信息
     * @return 结果
     */
    @Override
    public int insertVaccineInfo(VaccineInfo vaccineInfo)
    {
        vaccineInfo.setCreateTime(DateUtils.getNowDate());
        return vaccineInfoMapper.insertVaccineInfo(vaccineInfo);
    }

    /**
     * 修改疫苗信息
     * 
     * @param vaccineInfo 疫苗信息
     * @return 结果
     */
    @Override
    public int updateVaccineInfo(VaccineInfo vaccineInfo)
    {
        vaccineInfo.setUpdateTime(DateUtils.getNowDate());
        return vaccineInfoMapper.updateVaccineInfo(vaccineInfo);
    }

    /**
     * 批量删除疫苗信息
     * 
     * @param ids 需要删除的疫苗信息ID
     * @return 结果
     */
    @Override
    public int deleteVaccineInfoByIds(Long[] ids)
    {
        return vaccineInfoMapper.deleteVaccineInfoByIds(ids);
    }

    /**
     * 删除疫苗信息信息
     * 
     * @param id 疫苗信息ID
     * @return 结果
     */
    @Override
    public int deleteVaccineInfoById(Long id)
    {
        return vaccineInfoMapper.deleteVaccineInfoById(id);
    }
}
